==> nxnode-3.0.0-83.x86_64.tar.gz: NX/scripts/restricted/nxtmpperm.sh <==
#nxsetup 1.1.1: following lines are added by rpm setup script of nxserver or nxworkstation, please don't modify this comments.
############################################################################
#                                                                          #
#  Copyright (c) 2001, 2007 NoMachine, http://www.nomachine.com.           #
#                                                                          #
#  NXSERVER, NX protocol compression and NX extensions to this software    #
#  are copyright of NoMachine. Redistribution and use of the present       #
#  software is allowed according to terms specified in the file LICENSE    #
#  which comes in the source distribution.                                 #
#                                                                          #
#  Check http://www.nomachine.com/licensing.html for applicability.        #
#                                                                          #
#  NX and NoMachine are trademarks of NoMachine S.r.l.                     #
#                                                                          #
#  All rigths reserved.                                                    #
#                                                                          #
############################################################################
ice_dir=/tmp/.ICE-unix;
x11_dir=/tmp/.X11-unix;

for dirname in $ice_dir $x11_dir ; do
{
  if (! [ -d $dirname ] )
  then
    mkdir $dirname
    if [ $? != 0 ];
    then
      echo "Warning: $0: cannot mkdir $dirname";
    fi
  fi

  if (! [ -O $dirname ] )
  then
    chown root:root $dirname
    if [ $? != 0 ];
    then
      echo "Warning: $0: cannot chown $dirname";
    fi
  fi

  chmod 1777 $dirname
  if [ $? != 0 ];
  then
    echo "Warning: $0: cannot chmod $dirname to 1777";
  fi
}
done

#end nxsetup 1.1.1

==> nxnode-3.1.0-6.x86_64.tar.gz: NX/scripts/restricted/nxtmpperm.sh <==
#!/bin/sh
############################################################################
#                                                                          #
#  Copyright (c) 2001, 2007 NoMachine, http://www.nomachine.com.           #
#                                                                          #
#  NXSERVER, NX protocol compression and NX extensions to this software    #
#  are copyright of NoMachine. Redistribution and use of the present       #
#  software is allowed according to terms specified in the file LICENSE    #
#  which comes in the source distribution.                                 #
#                                                                          #
#  Check http://www.nomachine.com/licensing.html for applicability.        #
#                                                                          #
#  NX and NoMachine are trademarks of NoMachine S.r.l.                     #
#                                                                          #
#  All rigths reserved.                                                    #
#                                                                          #
############################################################################
ice_dir=/tmp/.ICE-unix;
x11_dir=/tmp/.X11-unix;

COMMAND_ECHO="/bin/echo"
NODE_ROOT="/usr/NX"

checkPpid() {

  if [ "x$1" = "x" ];
  then
    $COMMAND_ECHO "Missing pid"
    return 1
  fi
  if [ ! -e /proc/$1/cmdline ];
  then
    $COMMAND_ECHO "Wrong pid: $1"
    return 1
  fi

  command=$(/bin/cat /proc/$1/cmdline)

  $COMMAND_ECHO "$command"
}

command=$(checkPpid $2)

if [ $? != 0 ];
then
  $COMMAND_ECHO "NX> 500 Error: $command"
  exit 1
fi

if [ "$command" != "$NODE_ROOT/bin/nxnode" ];
then
  $COMMAND_ECHO "NX> 500 Error: Only the nxnode can run this script.";
  exit 1
fi

for dirname in $ice_dir $x11_dir ; do
{
  if (! [ -d $dirname ] )
  then
    /bin/mkdir $dirname
    if [ $? != 0 ];
    then
      echo "Warning: $0: cannot mkdir $dirname";
    fi
  fi

  if (! [ -O $dirname ] )
  then
    /bin/chown root:root $dirname
    if [ $? != 0 ];
    then
      echo "Warning: $0: cannot chown $dirname";
    fi
  fi

  /bin/chmod 1777 $dirname
  if [ $? != 0 ];
  then
    echo "Warning: $0: cannot chmod $dirname to 1777";
  fi
}
done

test -x /sbin/restorecon && /sbin/restorecon -v /tmp/.X11-unix
